The LinkML Ecosystem — linkml documentation

# The LinkML Ecosystem

LinkML is part of a growing ecosystem of tools:

## Tools that build off LinkML

### Data Harmonizer

- DataHarmonizer is a ontology-based curation tool that is being adapter to LinkML

### Bootstrapping Models

- linkml-model-enrichment bootstraps schemas from existing structured and semi-structured sources

### Templated OWL generation

- linkml-owl enables generation of complex OWL axioms from datamodels